%define major		1
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

Summary:	Netfilter Tables userspace utilities
Name:		nftables
Version:	1.1.1
Release:	%mkrel 1
License:	GPLv2
Group:		System/Kernel and hardware
URL:		https://netfilter.org/projects/nftables/
Source0:	https://www.netfilter.org/projects/nftables/files/nftables-%{version}.tar.xz
Source1:	https://www.netfilter.org/projects/nftables/files/nftables-%{version}.tar.xz.sig
Source2:        coreteam-gpg-key-0xD55D978A8A1420E4.txt
Source3:        nftables.service
Source4:        nftables.conf
Source5:        main.nft
Source6:        router.nft
Source7:        nat.nft

BuildRequires:	asciidoc
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gmp-devel
BuildRequires:	libedit-devel
BuildRequires:	readline-devel
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(libmnl) >= 1.0.4
BuildRequires:	pkgconfig(libnftnl) >= 1.2.8
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(xtables)

%description
Netfilter Tables userspace utilities.

#------------------------------------------------

%package -n	%{libname}
Summary:	Netfilter Tables userspace utilities
Group:		System/Libraries

%description -n	%{libname}
Netfilter Tables userspace utilities.

#------------------------------------------------

%package -n	%{develname}
Summary:	Development package for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n	%{develname}
Header files for development with %{name}.

#------------------------------------------------

%package -n	python3-nftables
Summary:	Python module providing an interface to libnftables
Group:		Development/Python
BuildArch:	noarch
Requires:	%{name} >= %{version}-%{release}
%{?python_provide:%python_provide python3-nftables}

%description -n python3-nftables
The nftables python module provides an interface to libnftables
via ctypes.

#------------------------------------------------

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1

%generate_buildrequires
cd py/
%pyproject_buildrequires

%build
autoreconf -fi
%configure --disable-silent-rules \
               --disable-static \
               --with-json \
               --with-xtables \
               --disable-python
%make_build

pushd py
%pyproject_wheel
popd

%install
%make_install

# Don't ship static lib (for now at least)
rm -f $RPM_BUILD_ROOT/%{_libdir}/libnftables.a

# drop vendor-provided configs, they are not really useful
rm -f $RPM_BUILD_ROOT/%{_datadir}/nftables/*.nft

chmod 644 $RPM_BUILD_ROOT/%{_mandir}/man8/nft*

mkdir -p $RPM_BUILD_ROOT/%{_unitdir}
cp -a %{SOURCE3} $RPM_BUILD_ROOT/%{_unitdir}/

mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig
cp -a %{SOURCE4} $RPM_BUILD_ROOT/%{_sysconfdir}/sysconfig/

cp %{SOURCE5} %{SOURCE6} %{SOURCE7} \
	$RPM_BUILD_ROOT/%{_sysconfdir}/nftables/

find $RPM_BUILD_ROOT/%{_sysconfdir} \
	\( -type d -exec chmod 0700 {} \; \) , \
	\( -type f -exec chmod 0600 {} \; \)

pushd py/
%pyproject_install
%pyproject_save_files nftables
popd

%post
%systemd_post nftables.service
%ldconfig_post

%preun
%systemd_preun nftables.service

%postun
%systemd_postun_with_restart nftables.service
%ldconfig_postun

%files
%license COPYING
%doc %{_docdir}/nftables/
%config(noreplace) %{_sysconfdir}/nftables/
%config(noreplace) %{_sysconfdir}/sysconfig/nftables.conf
%{_sbindir}/nft
%{_mandir}/man5/libnftables-json.5*
%{_mandir}/man8/nft*
%{_unitdir}/nftables.service

%files -n %{libname}
%license COPYING
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%license COPYING
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_mandir}/man3/libnftables.3*

%files -n python3-nftables -f %{pyproject_files}


%changelog
* Sat Nov 16 2024 wally <wally> 1.1.1-1.mga10
+ Revision: 2116163
- new version 1.1.1

* Sun Dec 10 2023 wally <wally> 1.0.6-4.mga10
+ Revision: 2017048
- another rebuild for py3.12
- rebuild for py3.12

* Fri Sep 15 2023 tmb <tmb> 1.0.6-2.mga10
+ Revision: 1986968
- add upstream fixes for coping with kernel 6.4.8 hardening for CVE-2023-4147

* Tue Jan 17 2023 luigiwalser <luigiwalser> 1.0.6-1.mga9
+ Revision: 1934022
- 1.0.6
- remove patch0 (fixed upstream)

* Fri Nov 18 2022 mrambo3501 <mrambo3501> 1.0.2-2.mga9
+ Revision: 1908722
- use Python's bundled distutils

* Fri May 13 2022 luigiwalser <luigiwalser> 1.0.2-1.mga9
+ Revision: 1858019
- add patch to fix includes for examples
- 1.0.2
- remove upstream patches

* Tue Mar 29 2022 umeabot <umeabot> 1.0.1-3.mga9
+ Revision: 1831663
- Mageia 9 Mass Rebuild

* Mon Feb 28 2022 mrambo3501 <mrambo3501> 1.0.1-2.mga9
+ Revision: 1786766
- rebuild for python-3.10

* Thu Jan 06 2022 luigiwalser <luigiwalser> 1.0.1-1.mga9
+ Revision: 1767116
- remove old unused patch
- actually apply new patches
- add upstream patches via fedora to fix build errors

* Sun Sep 26 2021 luigiwalser <luigiwalser> 1.0.0-2.mga9
+ Revision: 1746516
- 1.0.0

* Thu Aug 05 2021 luigiwalser <luigiwalser> 0.9.9-1.mga9
+ Revision: 1739680
- 0.9.9

* Thu Mar 18 2021 neoclust <neoclust> 0.9.8-2.mga9
+ Revision: 1704349
- Rebuild against python 3.9

* Sat Jan 16 2021 luigiwalser <luigiwalser> 0.9.8-1.mga8
+ Revision: 1672033
- 0.9.8

* Mon Nov 02 2020 luigiwalser <luigiwalser> 0.9.7-1.mga8
+ Revision: 1641673
- 0.9.7

* Sat Sep 05 2020 anaselli <anaselli> 0.9.6-1.mga8
+ Revision: 1622541
- Version 0.9.6

* Sat Sep 05 2020 anaselli <anaselli> 0.9.3-1.mga8
+ Revision: 1622480
- Version 0.9.3

* Wed Feb 19 2020 umeabot <umeabot> 0.9.2-3.mga8
+ Revision: 1542549
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Jan 05 2020 tv <tv> 0.9.2-2.mga8
+ Revision: 1476621
- rebuild for new readline

* Wed Nov 06 2019 daviddavid <daviddavid> 0.9.2-1.mga8
+ Revision: 1458504
- new version: 0.9.2
- now libmajor is 1
- enable new Python 3 support
- enable libxtables support
- enable json output support

* Sun Dec 30 2018 luigiwalser <luigiwalser> 0.9.0-3.mga7
+ Revision: 1346817
- rebuild for libnftnl

* Sun Sep 23 2018 umeabot <umeabot> 0.9.0-2.mga7
+ Revision: 1299738
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 daviddavid <daviddavid> 0.9.0-1.mga7
+ Revision: 1237612
- new version: 0.9.0
- add new lib and devel sub-packages

* Mon Jan 01 2018 daviddavid <daviddavid> 0.8-1.mga7
+ Revision: 1189027
- new version: 0.8

* Sun Jan 01 2017 luigiwalser <luigiwalser> 0.7-1.mga6
+ Revision: 1078970
- 0.7

* Wed Aug 10 2016 luigiwalser <luigiwalser> 0.6-1.mga6
+ Revision: 1045410
- 0.6

* Tue Feb 16 2016 umeabot <umeabot> 0.5-2.mga6
+ Revision: 961751
- Mageia 6 Mass Rebuild

* Tue Nov 17 2015 oden <oden> 0.5-1.mga6
+ Revision: 903746
- imported package nftables


* Tue Nov 17 2015 Oden Eriksson <oe@nux.se> 1.0.5-1
- initial Mageia package (fedora import)

* Thu Sep 17 2015 Kevin Fenzi <kevin@scrye.com> 0.5-1
- Update to 0.5

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:0.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jan 10 2015 Kevin Fenzi <kevin@scrye.com> 0.4-2
- Add patch to fix nft -f dep gen.

* Fri Dec 26 2014 Kevin Fenzi <kevin@scrye.com> 0.4-1
- Update to 0.4
- Add Epoch to fix versioning. 

* Wed Sep 03 2014 Kevin Fenzi <kevin@scrye.com> 0.100-4.20140903git
- Update to 20140903 snapshot

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.100-4.20140704git
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 04 2014 Kevin Fenzi <kevin@scrye.com> 0.100-3.20140704git
- Update to new snapshot

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.100-2.20140426git
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Apr 26 2014 Kevin Fenzi <kevin@scrye.com> 0.100-1.20140426git
- Update t0 20140426

* Sun Mar 30 2014 Kevin Fenzi <kevin@scrye.com> 0.100-1.20140330git
- Update to 20140330 snapshot
- Sync versions to be post 0.100 release.

* Wed Mar 26 2014 Kevin Fenzi <kevin@scrye.com> 0-0.7.20140326git
- Update to 20140326 snapshot
- Fix permissions on man pages. 

* Mon Mar 24 2014 Kevin Fenzi <kevin@scrye.com> 0-0.6.20140324git
- Update to 20140324 snapshot

* Fri Mar 07 2014 Kevin Fenzi <kevin@scrye.com> 0-0.5.20140307git
- Update to 20140307

* Sat Jan 25 2014 Kevin Fenzi <kevin@scrye.com> 0-0.4.20140125git
- Update to 20140125 snapshot

* Sat Jan 18 2014 Kevin Fenzi <kevin@scrye.com> 0-0.3.20140118git
- Update to 20140118 snapshot
- Fixed License tag to be correct
- Fixed changelog
- nft scripts now use full path for nft
- Fixed man page building
- Dropped unneeded rm in install
- Patched build to not be silent. 

* Tue Dec 03 2013 Kevin Fenzi <kevin@scrye.com> 0-0.2.20131202git
- Use upstream snapshots for source.
- Use 0 for version. 

* Sat Nov 30 2013 Kevin Fenzi <kevin@scrye.com> 0-0.1
- initial version for Fedora review
